==> apache-camel-3.0.1-src.zip: apache-camel-3.0.1/components/camel-cdi/src/main/java/org/apache/camel/cdi/CdiCamelContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.cdi;

import org.apache.camel.impl.DefaultCamelContext;

/**
 * CDI {@link org.apache.camel.CamelContext} class that can be extended
 * to declare custom Camel context beans. Camel CDI is capable of managing
 * any bean that implements {@code org.apache.camel.CamelContext},
 * so that directly extending {@link org.apache.camel.impl.DefaultCamelContext}
 * is an option to avoid having to depend on Camel CDI specific API, e.g.:
 *
 * <pre><code>
 * {@literal @}ApplicationScoped
 * {@literal @}ContextName("foo")
 * public class FooCamelContext extends DefaultCamelContext {
 * }
 * </code></pre>
 */
@Vetoed
public class CdiCamelContext extends DefaultCamelContext {

}

==> apache-camel-3.6.0-src.zip: apache-camel-3.6.0/components/camel-cdi/src/main/java/org/apache/camel/cdi/CdiCamelContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.cdi;

import org.apache.camel.TypeConverter;
import org.apache.camel.impl.DefaultCamelContext;

/**
 * CDI {@link org.apache.camel.CamelContext} class that can be extended to declare custom Camel context beans. Camel CDI
 * is capable of managing any bean that implements {@code org.apache.camel.CamelContext}, so that directly extending
 * {@link org.apache.camel.impl.DefaultCamelContext} is an option to avoid having to depend on Camel CDI specific API,
 * e.g.:
 *
 * <pre>
 * <code>
 * {@literal @}ApplicationScoped
 * {@literal @}ContextName("foo")
 * public class FooCamelContext extends DefaultCamelContext {
 * }
 * </code>
 * </pre>
 */
@Vetoed
public class CdiCamelContext extends DefaultCamelContext {

    @Override
    protected boolean eagerCreateTypeConverter() {
        // camel-cdi is complex so we cant optimize
        return false;
    }

    @Override
    public TypeConverter getTypeConverter() {
        return getOrCreateTypeConverter();
    }
}
